@@ -15,7 +15,7 @@ class FuncionarioLogin(core.usr.models.Profile):
 class Funcionario(core.models.Log, core.models.PessoaLog):
     matricula = models.CharField(max_length=200, primary_key=True)
     cargo = models.ForeignKey('funcionario.Cargo', on_delete=models.DO_NOTHING, null=True)
-    imagem = models.FileField(upload_to='fotos/funcionarios', default='fotos/no-photo.png', null=True)
+    imagem = models.FileField(upload_to='fotos/funcionarios', default='fotos/sem-foto.png', null=True)
 
     class Meta(core.models.Log.Meta):
         abstract = False
